#include <iostream>
#include <vector>
#include <cassert>
#include <map>
#include <algorithm>

using ll = long long;
#define MIN(a, b) (((a) < (b)) ? (a) : (b))
#define MAX(a, b) (((a) < (b)) ? (b) : (a))

int const nmax = 100000;
std::pair<int,int> v[1 + nmax];

struct Query{
  int time;
  int x;
  int x2;
  int val;
  bool operator < (Query a) {
    if(time != a.time)
      return time < a.time;
    else
      return val < a.val;
  }
};

std::vector<Query> queries;
std::map<int, int> mp;

void normalize() {
  std::vector<int> aux;
  for(int i = 0; i < queries.size(); i++) {
    aux.push_back(queries[i].x);
    aux.push_back(queries[i].x2);
  }
  std::sort(aux.begin(), aux.end());
  aux.erase(std::unique(aux.begin(), aux.end()), aux.end());
  for(int i = 0; i < aux.size(); i++)
    mp[aux[i]] = 1 + i;
  for(int i = 0; i < queries.size(); i++) {
    queries[i].x = mp[queries[i].x];
    queries[i].x2 = mp[queries[i].x2];
  }
}
class SegmentTree{
private:
  std::vector<int> aint;
  std::vector<int> lazy;
public:
  SegmentTree(int n) {
    aint.resize(1 + 4 * n);
    lazy.resize(1 + 4 * n);
  }
  void cleannode(int node, int from, int to) {
    if(from < to) {
      int mid = (from + to) / 2;
      lazy[node * 2] += lazy[node];
      lazy[node * 2 + 1] += lazy[node];
    }
    aint[node] += lazy[node];
    lazy[node] = 0;
  }
  void computenode(int node, int from, int to) {
    if(from < to) {
      aint[node] = std::max(aint[node * 2], aint[node * 2 + 1]);
    }
  }
  void update(int node, int from, int to, int x, int y, int val) {
    if(from == x && to == y) {
      lazy[node] += val;
      cleannode(node, from, to);
    } else {
      int mid = (from + to) / 2;
      cleannode(node * 2, from, mid);
      cleannode(node * 2 + 1, mid + 1, to);
      if(x <= mid)
        update(node * 2, from, mid, x, std::min(y, mid), val);
      if(mid + 1 <= y)
        update(node * 2 + 1, mid + 1, to, std::max(mid + 1, x), y, val);
      computenode(node, from, to);
    }
  }
  int query() {
    return aint[1];
  }
};

int main() {
  std::ios::sync_with_stdio(0);
  std::cin.tie(0);

  int n, w, h;
  std::cin >> n >> w >> h;
  for(int i = 1;i <= n; i++)
    std::cin >> v[i].first >> v[i].second;
  for(int i = 1;i <= n; i++){
    queries.push_back({v[i].first, v[i].second, v[i].second + h, 1});
    queries.push_back({v[i].first + w + 1, v[i].second, v[i].second + h, -1});
  }
  normalize();
  int _range = n * 2;
  SegmentTree aint(_range);
  int result = 0;
  std::sort(queries.begin(), queries.end());

  for(int i = 0; i < queries.size(); i++) {
    aint.update(1, 1, _range, queries[i].x, queries[i].x2, queries[i].val);
    result = std::max(result, aint.query());
  }
  std::cout << result;
  return 0;
}
