#include <bits/stdc++.h>

using namespace std;

class SegmentTree {
public:
    vector<int> a;
    int n;

    SegmentTree(int sz): a(4 * sz), n(sz) {
    }

    void set(int v, int vl, int vr, int i, int x) {
        if(vr - vl == 1) {
            a[v] = x;
            return;
        }
        int vm = (vl + vr) / 2;
        if(i < vm) {
            set(v * 2, vl, vm, i, x);
        } else {
            set(v * 2 + 1, vm, vr, i, x);
        }
        a[v] = a[v * 2] + a[v * 2 + 1];
    }
    void set(int i, int x) {
        set(1, 0, n, i, x);
    }

    int get(int v, int vl, int vr, int l, int r) {
        if(vl == l && vr == r) {
            return a[v];
        }
        int vm = (vl + vr) / 2;
        if(r <= vm) {
            return get(v * 2, vl, vm, l, r);
        } else if(l >= vm) {
            return get(v * 2 + 1, vm, vr, l, r);
        } else {
            return get(v * 2, vl, vm, l, vm) + get(v * 2 + 1, vm, vr, vm, r);
        }
    }
    int get(int l, int r) {
        return get(1, 0, n, l, r);
    }
    int get(int i) {
        return get(i, i + 1);
    }
};

class SegmentTreeMax {
public:
    vector<int> a;
    vector<int> mod;
    int n;

    SegmentTreeMax(int sz): a(4 * sz, -1000000000), mod(4 * sz), n(sz) {
    }

    void push(int v, int vl, int vr) {
        if(vr - vl > 1) {
            mod[v * 2] += mod[v];
            mod[v * 2 + 1] += mod[v];
        }
        a[v] += mod[v];
        mod[v] = 0;
    }

    void inc(int v, int vl, int vr, int l, int r, int x) {
        push(v, vl, vr);
        if(vl == l && vr == r) {
            mod[v] += x;
            return;
        }
        int vm = (vl + vr) / 2;
        if(r <= vm) {
            inc(v * 2, vl, vm, l, r, x);
        } else if(l >= vm) {
            inc(v * 2 + 1, vm, vr, l, r, x);
        } else {
            inc(v * 2, vl, vm, l, vm, x);
            inc(v * 2 + 1, vm, vr, vm, r, x);
        }
        push(v * 2, vl, vm);
        push(v * 2 + 1, vm, vr);
        a[v] = max(a[v * 2], a[v * 2 + 1]);
    }
    void inc(int l, int r, int x) {
        inc(1, 0, n, l, r, x);
    }

    int get(int v, int vl, int vr, int l, int r) {
        push(v, vl, vr);
        if(vl == l && vr == r) {
            return a[v];
        }
        int vm = (vl + vr) / 2;
        if(r <= vm) {
            return get(v * 2, vl, vm, l, r);
        } else if(l >= vm) {
            return get(v * 2 + 1, vm, vr, l, r);
        } else {
            return max(get(v * 2, vl, vm, l, vm), get(v * 2 + 1, vm, vr, vm, r));
        }
    }
    int get(int l, int r) {
        int res = get(1, 0, n, l, r);
        return res;
    }
    int get(int i) {
        return get(i, i + 1);
    }
};


vector<int> yy;
int h;
SegmentTreeMax length_by_y(100000);
SegmentTree cnt_by_y(100000);

void add_point(int y) {
    int y_minus_h = lower_bound(yy.begin(), yy.end(), y - h) - yy.begin();
    int y_plus_h = upper_bound(yy.begin(), yy.end(), y + h) - yy.begin();
    y = lower_bound(yy.begin(), yy.end(), y) - yy.begin();

    cnt_by_y.set(y, cnt_by_y.get(y) + 1);

    length_by_y.inc(y_minus_h, y, 1);
    int cnt = cnt_by_y.get(y, y_plus_h);
    length_by_y.inc(y, y + 1, cnt - length_by_y.get(y));
}

void remove_point(int y) {
    int y_minus_h = lower_bound(yy.begin(), yy.end(), y - h) - yy.begin();
    y = lower_bound(yy.begin(), yy.end(), y) - yy.begin();

    length_by_y.inc(y_minus_h, y, -1);
    length_by_y.inc(y, y + 1, -1000000000 - length_by_y.get(y));
}

int get_value() {
    return length_by_y.get(0, length_by_y.n);
}

signed main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);

    int n;
    cin >> n;

    int w;
    cin >> w >> h;

    vector< pair<int, int> > points;
    for(int i = 0; i < n; i++) {
        int x, y;
        cin >> x >> y;
        points.emplace_back(x, y);
        yy.push_back(y);
    }
    sort(points.begin(), points.end());
    sort(yy.begin(), yy.end());
    yy.erase(unique(yy.begin(), yy.end()), yy.end());

    int i = 0;
    int ans = 0;
    for(int j = 0; j < points.size(); j++) {
        add_point(points[j].second);
        while(points[j].first - points[i].first > w) {
            remove_point(points[i].second);
            i++;
        }
        ans = max(ans, get_value());
    }
    cout << ans << endl;

    return 0;
}
