#include <iostream>
#include <map>
#include <functional>

#define ENDL '\n'

namespace {
template <class T>
using vec = std::vector<T>;

auto point_count(std::multimap<int, int>& points, int x, int y) {
    auto res = 0;
    auto eq = points.equal_range(x);

    auto l = eq.first, r = eq.second;
    for (auto it = l; it != r; ++it) {
        if (it->second == y) {
            ++res;
        }
    }

    return res;
}

auto prefix_res(vec<vec<int>>& pr, int li, int lj, int i, int j) {
    if (i >= pr.size() || j >= pr[0].size()) {
        return 0;
    }

    auto curr_count = pr[i][j];
    // std::cout << pr[i][j];

    auto bi = li - 1;
    if (bi >= 0) {
        curr_count -= pr[bi][j];
        // std::cout << " - " << pr[bi][j];
    }

    auto bj = lj - 1;
    if (bj >= 0) {
        curr_count -= pr[i][bj];
        // std::cout << " - " << pr[i][bj];
    }

    if (bi >= 0 && bj >= 0) {
        curr_count += pr[bi][bj];
        // std::cout << " + " << pr[bi][bj];
    }

    // std::cout << " = " << curr_count << ENDL;

    return curr_count;
}
} // namespace

int main() {
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(nullptr);
    std::cout.tie(nullptr);

    int n, w, h;
    std::cin >> n >> w >> h;

    std::multimap<int, int> points;

    int x, y;
    auto max_x = 0, max_y = 0;

    while (n--) {
        std::cin >> x >> y;
        points.emplace(x, y);

        max_x = std::max(max_x, x);
        max_y = std::max(max_y, y);
    }

    vec<vec<int>> pr(max_x + 1, vec<int>(max_y + 1, 0));
    for (auto i = 0; i <= max_x; ++i) {
        for (auto j = 0; j <= max_y; ++j) {
            auto li = i - 1;
            if (li >= 0) {
                pr[i][j] += pr[li][j];
            }

            auto lj = j - 1;
            if (lj >= 0) {
                pr[i][j] += pr[i][lj];
            }

            if (li >= 0 && lj >= 0) {
                pr[i][j] -= pr[li][lj];
            }

            pr[i][j] += point_count(points, i, j);
        }
    }

    /*for (auto i = 0; i <= max_x; ++i) {
        for (auto j = 0; j <= max_y; ++j) {
            std::cout << pr[i][j] << " ";
        }
        std::cout << ENDL;
    }*/

    auto max_count = 0;

    for (auto i = w; i <= max_x; ++i) {
        for (auto j = h; j <= max_y; ++j) {
            auto li = i - w;
            auto lj = j - h;

            max_count = std::max(max_count, prefix_res(pr, i - w, j - h, i, j));
            max_count = std::max(max_count, prefix_res(pr, i, j, i + w, i + h));
        }
    }

    std::cout << max_count << ENDL;

    return 0;
}
