#include <algorithm>
#include <iostream>
#include <vector>
#include <queue>
#include <list>
#include <set>
#include <map>

using namespace std;

const int MAXN = 1e5 + 5;

struct Point
{
    int x, y;

    Point(){}
    Point(int x, int y)
    {
        this->x = x;
        this->y = y;
    }
};

struct SegmentTree
{
    int maxVal, lazy;

    int l, r;
    SegmentTree *L, *R;

    SegmentTree(){}
    SegmentTree(int l, int r)
    {
        this->l = l;
        this->r = r;

        this->L = nullptr;
        this->R = nullptr;

        maxVal = 0;
        lazy = 0;
    }

    void build()
    {
        if(l==r) return;

        L = new SegmentTree(l, (l+r)/2);
        R = new SegmentTree((l+r)/2+1, r);

        L->build();
        R->build();
    }

    void updateLazy()
    {
        maxVal += lazy;
        if(l!=r)
        {
            L->lazy += lazy;
            R->lazy += lazy;
        }

        lazy = 0;
    }

    void recalc()
    {
        maxVal = max(L->maxVal, R->maxVal);
    }

    void update(int ql, int qr, int change)
    {
        updateLazy();

        if(ql>=l && qr<=r)
        {
            maxVal += change;
            if(l!=r)
            {
                L->lazy += change;
                R->lazy += change;
            }

            return;
        }
        if(qr<l || ql>r) return;

        L->update(ql, qr, change);
        R->update(ql, qr, change);
        recalc();
    }

    void setValue(int q, int value)
    {
        updateLazy();

        if(q==l && l==r)
        {
            maxVal = value;
            return;
        }
        if(q<l || q>r) return;

        L->setValue(q, value);
        R->setValue(q, value);
        recalc();
    }
};

struct PointsKeeper
{
    int w, h;
    list <Point> active;
    multiset <pair <int, int>> activeSet;//{x, y}

    SegmentTree *T;
    set <int> allX;
    map <int, int> codeX;
    map <int, int> xCnt;

    PointsKeeper(){}
    PointsKeeper(int w, int h, vector <Point> points)
    {
        this->w = w;
        this->h = h;

        this->initTrees(points);
    }

    void initTrees(vector <Point> points)
    {
        for(Point p: points) allX.insert(p.x);

        int ind = 0;
        for(int x: allX) codeX[x] = ind, ind++;

        T = new SegmentTree(0, codeX.size()-1);
        T->build();
    }

    void addPoint(Point P)
    {
        xCnt[P.x]++;
        active.push_back(P);
        activeSet.insert({P.x, P.y});

        while((*active.begin()).y<P.y-h) removePoint();

        int cnt = 0;
        for(pair <int, int> item: activeSet)
            if(item.first>=P.x-w) cnt++;

        T->setValue(codeX[P.x], cnt);
    }

    void removePoint()
    {
        Point P = *active.begin();

        xCnt[P.x]--;
        activeSet.erase({P.x, P.y});
        active.erase(active.begin());

        if(xCnt[P.x]==0) T->setValue(codeX[P.x], -MAXN*22);
        for(pair <int, int> item: activeSet)
           if(item.first<=P.x+w) T->update(codeX[item.first], codeX[item.first], -1);
    }

    int evalBest()
    {
        /*
        int ans = 0;
        for(auto it = activeSet.begin();it!=activeSet.end();it++)
        {
            int cnt = 0;
            for(auto it1 = it;it1!=activeSet.end();it1++)
            {
                if(it1->first>it->first+w) break;
                cnt++;
            }

            ans = max(ans, cnt);
        }
        */

        return T->maxVal;
    }
};

int main()
{
    ios::sync_with_stdio(false);
    cin.tie(NULL);

    int n;
    int w, h;
    vector <Point> points;

    cin >> n;
    cin >> w >> h;
    for(int i = 0;i<n;i++)
    {
        int x, y;
        cin >> x >> y;

        points.push_back(Point(x, y));
    }

    sort(points.begin(), points.end(),
    [](Point A, Point  B)
    {
        if(A.y!=B.y) return A.y<B.y;
        return A.x<B.x;
    });

    int ans = 0;
    PointsKeeper yoanko(w, h, points);

    for(Point p: points)
    {
        //cout << p.x << " ------ " << p.y << '\n';

        yoanko.addPoint(p);
        //cout << "ADDED" << '\n';

        ans = max(ans, yoanko.evalBest());
    }

    cout << ans << '\n';
}
