#include <bits/stdc++.h>

#pragma GCC optimize "-O3"

#define endl '\n'
#define trace(x) cerr << #x << " = " << x << endl

using namespace std;

struct Event {
    int x;
    int y;
    int type;

    Event(int x, int y, int type) {
        this->x = x;
        this->y = y;
        this->type = type;
    }

    bool operator <(const Event &other) const {
        if (this->x == other.x) {
            if (this->type == other.type) {
                return (this->y < other.y);
            }

            return (this->type > other.type);
        }

        return (this->x < other.x);
    }
};

struct FenwickTree {
    vector<int> tree;

    void init(int n) {
        this->tree.resize(n + 1, 0);
    }

    void update(int x, int delta) {
        for (int i = x; i < (int)this->tree.size(); i += i & -i) {
            tree[i] += delta;
        }
    }

    int query(int x) {
        int answer = 0;

        for (int i = x; i > 0; i -= i & -i) {
            answer += tree[i];
        }

        return answer;
    }

    int query(int ql, int qr) {
        int answer = query(qr);
        if (ql > 1) {
            answer -= query(ql - 1);
        }

        return answer;
    }
};

void setIO() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
}

int n, w, h;
vector<pair<int, int>> points;
int maxX = 0, maxY = 0;

void read() {
    cin >> n >> w >> h;

    points.resize(n);
    for (int i = 0; i < n; i++) {
        cin >> points[i].first >> points[i].second;

        maxX = max(maxX, points[i].first);
        maxY = max(maxY, points[i].second);
    }
}

void solve() {
    vector<Event> events;
    for (int i = 0; i < n; i++) {
        events.emplace_back(points[i].first, points[i].second, 1);
        events.emplace_back(points[i].first + w, points[i].second, -1);
    }

    sort(events.begin(), events.end());

    FenwickTree tree;
    tree.init(maxY + 1);

    int answer = 0;

    for (Event &i : events) {
        if (i.type == 1) {
            tree.update(i.y + 1, 1);

            if (i.x >= w && i.y >= h) {
                answer = max(answer, tree.query(i.y - h + 1, i.y + 1));
            }
        } else {
            tree.update(i.y + 1, -1);
        }
    }

    cout << answer << endl;
}

int main() {
    setIO();

    read();

    solve();
}
