#include <bits/stdc++.h>

#pragma GCC optimize "-O3"

#define endl '\n'
#define trace(x) cerr << #x << " = " << x << endl

using namespace std;

struct Event {
    int x;
    int y;
    int type;

    Event(int x, int y, int type) {
        this->x = x;
        this->y = y;
        this->type = type;
    }

    bool operator <(const Event &other) const {
        if (this->x == other.x) {
            if (this->type == other.type) {
                return (this->y < other.y);
            }

            return (this->type > other.type);
        }

        return (this->x < other.x);
    }
};

struct SegmentTree {
    int n;
    vector<int> tree;
    vector<int> lazy;

    void init(int n) {
        this->n = n;
        tree.resize(4 * (n + 1), 0);
        lazy.resize(4 * (n + 1), 0);
    }

    void push(int node, int low, int high) {
        if (lazy[node] != 0) {
            tree[node] += lazy[node];

            if (low != high) {
                lazy[node * 2] += lazy[node];
                lazy[node * 2 + 1] += lazy[node];
            }

            lazy[node] = 0;
        }
    }

    void update(int node, int low, int high, int ql, int qr, int delta) {
        push(node, low, high);

        if (high < ql || low > qr) {
            return;
        }

        if (low >= ql && high <= qr) {
            lazy[node] += delta;
            push(node, low, high);
            return;
        }

        int middle = low + (high - low) / 2;
        update(node * 2, low, middle, ql, qr, delta);
        update(node * 2 + 1, middle + 1, high, ql, qr, delta);

        tree[node] = min(tree[node * 2], tree[node * 2 + 1]);
    }

    int query(int node, int low, int high, int ql, int qr) {
        push(node, low, high);

        if (high < ql || low > qr) {
            return 1e9;
        }

        if (low >= ql && high <= qr) {
            return tree[node];
        }

        int middle = low + (high - low) / 2;
        int p1 = query(node * 2, low, middle, ql, qr);
        int p2 = query(node * 2 + 1, middle + 1, high, ql, qr);

        return min(p1, p2);
    }

    void update(int l, int r, int delta) {
        update(1, 0, n - 1, l, r, delta);
    }

    int query(int l, int r) {
        return query(1, 0, n - 1, l, r);
    }
};

void setIO() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
}

int n, w, h;
vector<pair<int, int>> points;
int maxX = 0, maxY = 0;

void read() {
    cin >> n >> w >> h;

    points.resize(n);
    for (int i = 0; i < n; i++) {
        cin >> points[i].first >> points[i].second;

        maxX = max(maxX, points[i].first);
        maxY = max(maxY, points[i].second);
    }
}

void solve() {
    vector<Event> events;
    for (int i = 0; i < n; i++) {
        events.emplace_back(points[i].first - w, points[i].second, 1);
        events.emplace_back(points[i].first + w, points[i].second, -1);
    }

    sort(events.begin(), events.end());

    SegmentTree tree;
    tree.init(maxY + 1);

    int answer = 0;

    for (Event &i : events) {
        if (i.type == 1) {
            tree.update(max(0, i.y - h), min(maxY, i.y + h), 1);
        }

        for (int i = 0; i <= maxY - h; i++) {
            answer = max(answer, tree.query(i, i + h));
        }

        if (i.type == -1) {
            tree.update(max(0, i.y - h), min(maxY, i.y + h), -1);
        }
    }

    cout << (answer - 1) << endl;
}

int main() {
    setIO();

    read();

    solve();
}
